<?php

function dark_top_travel_customize_register( $wp_customize ) {

	class Dark_Top_Travel_Switch_Control extends WP_Customize_Control{

		public $type = 'switch';

		public $on_off_label = array();

		public function __construct( $manager, $id, $args = array() ){
	        $this->on_off_label = $args['on_off_label'];
	        parent::__construct( $manager, $id, $args );
	    }

		public function render_content(){
	    ?>
		    <span class="customize-control-title">
				<?php echo esc_html( $this->label ); ?>
			</span>

			<?php if( $this->description ){ ?>
				<span class="description customize-control-description">
				<?php echo wp_kses_post( $this->description ); ?>
				</span>
			<?php } ?>

			<?php
				$switch_class = ( $this->value() == 'true' ) ? 'switch-on' : '';
				$on_off_label = $this->on_off_label;
			?>
			<div class="onoffswitch <?php echo esc_attr( $switch_class ); ?>">
				<div class="onoffswitch-inner">
					<div class="onoffswitch-active">
						<div class="onoffswitch-switch"><?php echo esc_html( $on_off_label['on'] ) ?></div>
					</div>

					<div class="onoffswitch-inactive">
						<div class="onoffswitch-switch"><?php echo esc_html( $on_off_label['off'] ) ?></div>
					</div>
				</div>	
			</div>
			<input <?php $this->link(); ?> type="hidden" value="<?php echo esc_attr( $this->value() ); ?>"/>
			<?php
	    }
	}

	class Dark_Top_Travel_Dropdown_Chooser extends WP_Customize_Control{

		public $type = 'dropdown_chooser';

		public function render_content(){
			if ( empty( $this->choices ) )
	                return;
			?>
	            <label>
	                <span class="customize-control-title">
	                	<?php echo esc_html( $this->label ); ?>
	                </span>

	                <?php if($this->description){ ?>
		            <span class="description customize-control-description">
		            	<?php echo wp_kses_post($this->description); ?>
		            </span>
		            <?php } ?>

	                <select class="dark-top-travel-chosen-select" <?php $this->link(); ?>>
	                    <?php
	                    foreach ( $this->choices as $value => $label )
	                        echo '<option value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . esc_html( $label ) . '</option>';
	                    ?>
	                </select>
	            </label>
			<?php
		}
	}


	class Dark_Top_Travel_Icon_Picker extends WP_Customize_Control{
		public $type = 'icon-picker';


		public function render_content(){
			$id = uniqid();
			?>
	            <label>
	                <span class="customize-control-title">
	                	<?php echo esc_html( $this->label ); ?>
	                </span>

	                <?php if($this->description){ ?>
		            <span class="description customize-control-description">
		            	<?php echo wp_kses_post($this->description); ?>
		            </span>
		            <?php } ?>

	                <input id="dark-top-travel-<?php echo esc_attr( $id ); ?>" placeholder="<?php esc_attr_e( 'Click here to select icon', 'dark-top-travel' ); ?>" class="dark-top_travel-icon-picker input" <?php $this->link(); ?> value="<?php echo esc_attr( $this->value() ); ?>" />
	            </label>
			<?php
		}
	}

	class Dark_Top_Travel_Dropdown_Category_Control extends WP_Customize_Control {

		public $type = 'dropdown-categories';

		public $taxonomy = '';

		public function __construct( $manager, $id, $args = array() ) {

			$taxonomy = 'category';
			if ( isset( $args['taxonomy'] ) ) {
				$taxonomy_exist = taxonomy_exists( esc_attr( $args['taxonomy'] ) );
				if ( true === $taxonomy_exist ) {
					$taxonomy = esc_attr( $args['taxonomy'] );
				}
			}
			$args['taxonomy'] = $taxonomy;
			$this->taxonomy = esc_attr( $taxonomy );

			parent::__construct( $manager, $id, $args );
		}

		public function render_content() {

			$tax_args = array(
				'hierarchical' => 0,
				'taxonomy'     => $this->taxonomy,
			);
			$taxonomies = get_categories( $tax_args );

		?>
	    <label>
	      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	      <?php if ( ! empty( $this->description ) ) : ?>
	      	<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
	      <?php endif; ?>
	       <select <?php $this->link(); ?> multiple>
				<?php
				printf( '<option value="%s" %s>%s</option>', '', selected( $this->value(), '', false ), '--None--' );
				?>
				<?php if ( ! empty( $taxonomies ) ) :  ?>
	            <?php foreach ( $taxonomies as $key => $tax ) :  ?>
					<?php
					printf( '<option value="%s" %s>%s</option>', esc_attr( $tax->term_id ), selected( $this->value(), $tax->term_id, false ), esc_html( $tax->name ) );
					?>
	            <?php endforeach ?>
				<?php endif ?>
	       </select>
	    </label>
	    <?php
		}
	}


	$wp_customize->remove_section( 'colors' );


	// Add Package section
	$wp_customize->add_section( 'dark_top_travel_package_section', array(
		'title'             => esc_html__( 'Package','dark-top-travel' ),
		'description'       => esc_html__( 'Package Section options.', 'dark-top-travel' ),
		'panel'             => 'top_travel_front_page_panel',
		'priority'			=> 45
	) );

	// Package content enable control and setting
	$wp_customize->add_setting( 'dark_top_travel_theme_options_package_section_enable', array(
		'default'			=> 	false,
		'sanitize_callback' => 'top_travel_sanitize_switch_control',
	) );

	$wp_customize->add_control( new Dark_Top_Travel_Switch_Control( $wp_customize, 'dark_top_travel_theme_options_package_section_enable', array(
		'label'             => esc_html__( 'Package Section Enable', 'dark-top-travel' ),
		'section'           => 'dark_top_travel_package_section',
		'on_off_label' 		=> top_travel_switch_options(),
	) ) );

	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'dark_top_travel_theme_options_package_section_enable', array(
			'selector'            => '.recommended-hotels-package .recommended-hotels-wrapper',
			'settings'            => 'dark_top_travel_theme_options_package_section_enable',
	    ) );
	}

	// package title setting and control
	$wp_customize->add_setting( 'dark_top_travel_theme_options_package_title', array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'dark_top_travel_theme_options_package_title', array(
		'label'           	=> esc_html__( 'Title', 'dark-top-travel' ),
		'section'        	=> 'dark_top_travel_package_section',
		'active_callback' 	=> 'dark_top_travel_is_package_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'dark_top_travel_theme_options_package_title', array(
			'selector'            => '.recommended-hotels-package h2.recommended-hotels-title',
			'settings'            => 'dark_top_travel_theme_options_package_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'dark_top_travel_package_title_partial',
	    ) );
	}

	$wp_customize->add_setting( 'dark_top_travel_theme_options_package_sub_title', array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'dark_top_travel_theme_options_package_sub_title', array(
		'label'           	=> esc_html__( 'Sub Title', 'dark-top-travel' ),
		'section'        	=> 'dark_top_travel_package_section',
		'active_callback' 	=> 'dark_top_travel_is_package_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'dark_top_travel_theme_options_package_sub_title', array(
			'selector'            => '.recommended-hotels-package p.recommended-hotels-subtitle',
			'settings'            => 'dark_top_travel_theme_options_package_sub_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'dark_top_travel_package_sub_title_partial',
	    ) );
	}

	$wp_customize->add_setting( 'dark_top_travel_theme_options_package_bg_image', array(
		'sanitize_callback' => 'top_travel_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dark_top_travel_theme_options_package_bg_image',
			array(
			'label'       		=> esc_html__( 'Background Image', 'dark-top-travel' ),
			'section'     		=> 'dark_top_travel_package_section',
			'active_callback'	=> 'dark_top_travel_is_package_section_enable',
	) ) );

	// Package content type control and setting
	$wp_customize->add_setting( 'dark_top_travel_theme_options_package_content_type', array(
		'sanitize_callback' => 'top_travel_sanitize_select',
	) );

	$wp_customize->add_control( 'dark_top_travel_theme_options_package_content_type', array(
		'label'             => esc_html__( 'Content Type', 'dark-top-travel' ),
		'section'           => 'dark_top_travel_package_section',
		'type'				=> 'select',
		'active_callback' 	=> 'dark_top_travel_is_package_section_enable',
		'choices'			=> array(
								'category'	=> esc_html__( 'Category', 'dark-top-travel' ),
								'trip-types'	=> esc_html__( 'Trip Type', 'dark-top-travel' ),
							),
	) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'dark_top_travel_theme_options_package_content_category', array(
		'sanitize_callback' => 'top_travel_sanitize_category_list',
	) ) ;

	$wp_customize->add_control( new Dark_Top_Travel_Dropdown_Category_Control( $wp_customize,'dark_top_travel_theme_options_package_content_category', array(
		'label'             => esc_html__( 'Select Multiple Category', 'dark-top-travel' ),
		'section'           => 'dark_top_travel_package_section',
		'type'              => 'dropdown-categories',
		'active_callback'	=> 'dark_top_travel_is_package_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'dark_top_travel_theme_options_package_content_trip_types', array(
		'sanitize_callback' => 'top_travel_sanitize_integers',
	) ) ;

	$wp_customize->add_control( new Dark_Top_Travel_Dropdown_Category_Control( $wp_customize,'dark_top_travel_theme_options_package_content_trip_types', array(
		'label'             => esc_html__( 'Select Multiple Trip Types', 'dark-top-travel' ),
		'section'           => 'dark_top_travel_package_section',
		'taxonomy'			=> 'itinerary_types',
		'type'              => 'dropdown-categories',
		'active_callback'	=> 'dark_top_travel_is_package_section_content_trip_types_enable'
	) ) );

	


}
add_action( 'customize_register', 'dark_top_travel_customize_register' );


function dark_top_travel_is_package_section_enable( $control ) {	
	return ( $control->manager->get_setting( 'dark_top_travel_theme_options_package_section_enable' )->value() );
}

function dark_top_travel_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_top_travel_theme_options_package_content_type' )->value();
	return dark_top_travel_is_package_section_enable( $control ) && ( 'category' == $content_type );
}
function dark_top_travel_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_top_travel_theme_options_package_content_type' )->value();
	return dark_top_travel_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}